<?php

namespace App\Model;
use Nette;

/**
 * Class for handling activities related to config
 * @package App\Model
 */
class ConfigManager {

    use Nette\SmartObject;

    private $config;
    private Nette\Database\Explorer $database;
    private $databaseConfiguration;

    public function __construct(array $config, Nette\Database\Explorer $database) {
        $this->config = $config;
        $this->database = $database;

        $this->databaseConfiguration = array();

        foreach($database->table('SETTING')->select('*') as $row) {
            $this->databaseConfiguration[$row['key']] = $row['value'];
        }
    }

    /**
     * Function returns config array
     * @return array
     */
    public function getConfig():array {
        return $this->config;
    }

    /**
     * Get identifier of actual period TSP cycle
     * @return int|null
     */
    public function getActualPeriod():int|null {
        if(isset($this->databaseConfiguration['actual_period'])) {
            return $this->databaseConfiguration['actual_period'];
        }

        return null;
    }

    /**
     * Function sets actual period settings
     * @param int $value
     * @return bool
     */
    public function setActualPeriod(int $value):bool {
        if($this->database->table('SETTING')->get('actual_period')->update([
            'value' => $value,
        ])) {
            $this->databaseConfiguration['actual_period'] = $value;
            return true;
        }

        return false;
    }

}