<?php

namespace App\Model;

use Nette;
use Nette\Mail\Message;

/**
 * Class for handling activities related to sending emails
 * @package App\Model
 */
class MailManager {

    use Nette\SmartObject;

    private Nette\Mail\Mailer $mailer;
    private ConfigManager $configManager;

    public function __construct(Nette\Mail\Mailer $mailer, ConfigManager $configManager) {
        $this->mailer = $mailer;
        $this->configManager = $configManager;
    }

    /**
     * Sending email for testing purpose
     * @param $email
     */
    public function sendTestEmail($email) {
        if($this->configManager->getConfig()['testing']['enabled']) {
            if($this->configManager->getConfig()['testing']['testMail']) {
                $email = $this->configManager->getConfig()['testing']['testMailAddress'];
            }
        }

        $msg = new Message();
        $msg->setFrom('PSTSP <pstsp@hintik.cz>')
            ->addTo($email)
            ->setSubject('Order Confirmation')
            ->setBody("Hello, Your order has been accepted.");

        $this->mailer->send($msg);
    }

    /**
     * Function sends email with recovery password token
     * @param $email
     * @param $token
     */
    public function sendForgetEmail($email, $token) {
        if($this->configManager->getConfig()['testing']['enabled']) {
            if($this->configManager->getConfig()['testing']['testMail']) {
                $email = $this->configManager->getConfig()['testing']['testMailAddress'];
            }
        }

        $msg = new Message();
        $msg->setFrom('PSTSP <pstsp@hintik.cz>')
            ->addTo($email)
            ->setSubject('Žádost o resetování hesla')
            ->setBody("Odkaz pro resetování hesla: http://localhost/recover/?token=$token");

        $this->mailer->send($msg);
    }

    /**
     * Functoin sends email with login and password to given email address
     * @param $email email address
     * @param $login user login
     * @param $password user password
     */
    public function sendLeaderCreated($email, $login, $password) {
        if($this->configManager->getConfig()['testing']['enabled']) {
            if($this->configManager->getConfig()['testing']['testMail']) {
                $email = $this->configManager->getConfig()['testing']['testMailAddress'];
            }
        }


        $msg = new Message();
        $msg->setFrom('PSTSP <pstsp@hintik.cz>')
            ->addTo($email)
            ->setSubject('Vytvoření konta vedoucího v PSTSP')
            ->setBody("Dobrý den, zasíláme Vám údaje pro přihlášení do aplikace PSTSP.
Vaše údaje:
    login: $login
    heslo: $password
    
Výrazně doporučujeme si heslo okamžitě po přihlášení změnit.");

        $this->mailer->send($msg);

    }

    /**
     * Function sends email with login and password to given email address
     * @param $email email address
     * @param $login user login
     * @param $password user password
     */
    public function sendMentorCreated($email, $login, $password) {
        if($this->configManager->getConfig()['testing']['enabled']) {
            if($this->configManager->getConfig()['testing']['testMail']) {
                $email = $this->configManager->getConfig()['testing']['testMailAddress'];
            }
        }

        $msg = new Message();
        $msg->setFrom('PSTSP <pstsp@hintik.cz>')
            ->addTo($email)
            ->setSubject('Vytvoření konta mentora v PSTSP')
            ->setBody("Dobrý den, zasíláme Vám údaje pro přihlášení do aplikace PSTSP.
Vaše údaje:
    login: $login
    heslo: $password
    
Výrazně doporučujeme si heslo okamžitě po přihlášení změnit.");

        $this->mailer->send($msg);

    }
}