<?php

namespace App\Model;

use Nette;
use Nette\Security\AuthenticationException;
use Nette\Security\IIdentity;
use Nette\Security\SimpleIdentity;

/**
 * Class for handling activities related to authentication
 * @package App\Model
 */
class MyAuthenticator implements Nette\Security\Authenticator {

    private $database;
    private $passwords;

    public function __construct(Nette\Database\Explorer $database, Nette\Security\Passwords $passwords) {
        $this->database = $database;
        $this->passwords = $passwords;
    }

    /**
     * Function to authenticate user
     * @param string $username user login
     * @param string $password user password
     * @return SimpleIdentity
     * @throws AuthenticationException
     */
    function authenticate(string $username, string $password): SimpleIdentity {

        $row = $this->database->table('USER')->where('login', $username)->fetch();

        if(!$row) {
            throw new Nette\Security\AuthenticationException('User not found.');
        }

        if(!$this->passwords->verify($password, $row->password)) {
            throw new Nette\Security\AuthenticationException('Neplatné heslo');
        }

        if($row->can_login == 0) {
            throw new Nette\Security\AuthenticationException('Uživatelský účet je pro přihlášení blokován.');
        }

        $role = $this->database->table('USER')->get($row->id)->ref('ROLE');
        //$team = $this->database->table('USER')->get($row->id)->ref('TEAM', 'team');

        if($role->id == RoleManager::$ROLE_LEADER_ID) {
            $contact = $row->ref('STUDENT');
            $contact_id = $row->student_id;
        } else {
            $contact = $row->ref('CONTACT');
            $contact_id = $row->contact_id;
        }

        return new SimpleIdentity(
            $row->id,
            $role->name,
            [
                'id' => $row->id,
                'login' => $row->login,
                'lastname' => $contact->lastname,
                'firstname' => $contact->firstname,
                'contact_id' => intval($contact_id),
            ]
        );
    }
}