<?php

namespace App\Model;

use Nette;

/**
 * Class for handling activities related to tags
 * @package App\Model
 */
class TagManager {
    use Nette\SmartObject;

    private Nette\Database\Explorer $database;

    public function __construct(Nette\Database\Explorer $database) {
        $this->database = $database;
    }

    public function getTag($assignmentId) {
        return $this->database->table('TAG')->get($assignmentId);
    }

    /**
     * Returns array [index of skill, name of skill] by team
     * @return array
     */
    public function getAllTags() {

        return $this->database->table("TAG")->order("name DESC")->fetchPairs("id","name");
    }

    /**
     * Returns array [index of skill, name of skill] applicable by team
     * @return array
     */
    public function getAllApplicableTags() {
        return $this->database->table("TAG")->where('applicable', 1)->order("name DESC")->fetchPairs("id","name");
    }

    /**
     * Function creates new tag from given parameters
     * @param string $label name of tag
     * @param int $applicable flag if is allowed to use (1 = yes; 0 = no)
     * @return bool
     */
    public function createTag(string $label, int $applicable) {

        $row = $this->database->table('TAG')->insert([
            'name' => $label,
            'applicable' => $applicable,
        ]);

        if($row) {
            return true;
        } else {
            return false;
        }
    }

    /**
     * Function to edit tag from given parameters
     * @param int $tagId tag identifier
     * @param string $label new name (label)
     * @param int $applicable new value for accessibility of this tag (1 = yes; 0 = no)
     */
    public function editTag(int $tagId, string $label, int $applicable) {
        $this->database->table('TAG')->get($tagId)->update([
            'name' => $label,
            'applicable' => $applicable,
        ]);
    }
}