<?php

namespace App\Presenters;

use App\Components\AssignmentCreationForm;
use App\Model\AssignmentManager;
use App\Model\RoleManager;
use Nette;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;
use Ublaboo\DataGrid\DataGrid;

/**
 * Presenter class to handle requests to page with assignment management
 */
class AssignmentManagementPresenter extends BasePresenter {
    /**
     * @var AssignmentCreationForm
     */
    protected AssignmentCreationForm $assignmentCreationForm;
    protected AssignmentManager $assignmentManager;

    public function __construct(AssignmentCreationForm $assignmentCreationForm, AssignmentManager $assignmentManager) {
        parent::__construct();

        $this->assignmentCreationForm = $assignmentCreationForm;
        $this->assignmentManager = $assignmentManager;
    }

    public function renderDefault() {
        $this->loggerManager->get('default')->info("AssignmentManagement page is loaded",["user_id"=>$this->getUser()->getId()]);

        $this->template->assignments = $this->database->table('ASSIGNMENT');
    }

    public function renderEdit($id) {

    }

    public function createComponentSimpleGrid($name) {
        $grid = new DataGrid($this, $name);

        $grid->setDataSource($this->database->table('ASSIGNMENT', 'a')->select("ASSIGNMENT.id,
         ASSIGNMENT.name, CONCAT(contact.firstname, ' ', contact.lastname) AS creator_name, period.label"));


        $grid->setTemplateFile(__DIR__ . '/templates/DataGrid/basicTemplate.latte');

        $grid->addColumnText('id', 'ID')->setSortable();
        //$grid->addColumnText('name', 'Název');
        $grid->addColumnLink('name', 'Název', 'Assignment:show', 'name', ['id'])->setSortable()->setFilterText();
        $grid->addColumnText('label', 'Období');
        $grid->addColumnText('creator_name', 'Zadavatel');

    }

    protected function createComponentAssignmentCreationForm(): Form {

        if($this->getAction() == 'edit') {
            $assignmentId = intval($this->getParameter('id'));

            if($assignmentId == 0) {
                throw new \Exception("Cannot create form with invalid id");
            }

            $form = $this->assignmentCreationForm->create($this->getUser()->id, intval($this->getParameter('id')));

            $form->onError[] = function () {
                $this->flashMessage('Chyba;Vyskytla se chyba při vytváření zadání.', 'bg-danger');
                $this->redirect('AssignmentManagement:');
            };

            $form->onSuccess[] = [$this, 'editAssignmentFormSucceeded'];
        } else if($this->getAction('create')) {
            $form = $this->assignmentCreationForm->create($this->getUser()->id);
            $form->onError[] = function () {
                $this->flashMessage('Chyba;Vyskytla se chyba při úpravě zadání.', 'bg-danger');
                $this->redirect('AssignmentManagement:');
            };
            $form->onSuccess[] = [$this, 'createAssignmentFormSucceeded'];
        }


        return $form;
    }


    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function createAssignmentFormSucceeded(Form $form, ArrayHash $values) {
        $assignment = $this->assignmentManager->createAssignment($values);
        $this->loggerManager->get('default')->notice('Assignment was created', [
            'user_identity' => $this->getUser()->getIdentity()->getData(),
            'assignment_id' => $assignment->id,
            'assignment_name' => $assignment->name,
        ]);
        $this->flashMessage('Úspěch;Zadání bylo přidáno.', 'bg-success');
        $this->redirect('AssignmentManagement:');
    }

    /**
     * Functions that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function editAssignmentFormSucceeded(Form $form, ArrayHash $values) {
        $assignment = $this->assignmentManager->editAssignment($values);
        $this->loggerManager->get('default')->notice('Assignment was edited', [
            'user_identity' => $this->getUser()->getIdentity()->getData(),
            'assignment_id' => $assignment->id,
            'assignment_name' => $assignment->name,
        ]);
        $this->flashMessage('Úspěch;Zadání bylo upraveno.', 'bg-success');
        $this->redirect('AssignmentManagement:');
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }


}