<?php

declare(strict_types=1);

namespace App\Presenters;

use App\Model\MeetingFacade;
use App\Model\ProjectManager;
use App\Model\RoleManager;
use Nette;

/**
 * Presenter class to handle requests to page with mentor management
 */
class MentorManagementPresenter extends BasePresenter {

    private ProjectManager $projectManager;
    private MeetingFacade $meetingFacade;

    public Nette\Database\Explorer $database;

    public function __construct(ProjectManager $projectManager, MeetingFacade $meetingFacade) {
        parent::__construct();

        $this->projectManager = $projectManager;
        $this->meetingFacade = $meetingFacade;
    }

    public function renderDefault() {
        $this->template->projects = $this->projectManager->getProjects();

        $this->loggerManager->get('default')->info("Mentored projects page is loaded",["user_id"=>$this->getUser()->getId()]);
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }
}