<?php

namespace App\Presenters;

use App\Components\PeriodCreationForm;
use App\Components\PeriodSettingForm;
use App\Model\MailManager;
use App\Model\PeriodManager;
use App\Model\RoleManager;
use App\Model\TeamManager;
use Nette;
use Nette\Application\UI\Form;

/**
 * Presenter class to handle requests to page with period management
 */
class PeriodManagementPresenter extends BasePresenter {

    protected PeriodSettingForm $periodSettingForm;
    protected PeriodCreationForm $periodCreationForm;
    protected PeriodManager $periodManager;

    public function __construct(PeriodSettingForm $periodSettingForm,
                                PeriodCreationForm $periodCreationForm,
                                PeriodManager $periodManager) {
        parent::__construct();

        $this->periodSettingForm = $periodSettingForm;
        $this->periodCreationForm = $periodCreationForm;
        $this->periodManager = $periodManager;
    }

    public function renderDefault() {

        $this->template->periods = $this->database->table('PERIOD');
    }

    public function createComponentPeriodSettingForm():Form {
        $form = $this->periodSettingForm->create();

        $form->onSuccess[] = function (Form $form, Nette\Utils\ArrayHash $values) {
            $this->flashMessage('Úspěch;Ročník změněn.', 'bg-success');
            $this->loggerManager->get('default')->notice('The period of the subject has changed',[
                'user_identity' => $this->user->getIdentity()->getData(),
                'period' => $values['period'],
            ]);
        };

        return $form;
    }

    public function createComponentPeriodCreationForm():Form {
        $form = $this->periodCreationForm->create();

        $form->onSuccess[] = function (Form $form, Nette\Utils\ArrayHash $values) {
            $this->flashMessage('Úspěch;Ročník vytvořen.', 'bg-success');

            $this->loggerManager->get('default')->notice('Subject Period was created', [
                'user_identity' => $this->user->getIdentity()->getData(),
            ]);
            $this->redirect('this');
        };

        return $form;
    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_GARANT)) {
            return true;
        }
        return false;
    }

}