<?php

namespace App\Presenters;

use App\Model\ProjectManager;
use App\Model\RoleManager;
use Nette;
use Ublaboo\DataGrid\DataGrid;

/**
 * Presenter class to handle requests to page with not mentored assignment
 */
class UnmentoratedAssignmentPresenter extends BasePresenter {

    public Nette\Database\Explorer $database;


    public function __construct(Nette\Database\Explorer $database) {
        parent::__construct();

        $this->database = $database;
    }

    public function renderDefault() {

        //TODO: Test if user has permission to see this page
        $this->loggerManager->get('default')->info("Unmentored assignment page is loaded",["user_id"=>$this->getUser()->getId()]);

    }

    public function createComponentSimpleGrid($name) {
        $grid = new DataGrid($this, $name);

        $a = array();
        $a['id'] = "DESC";

        $grid->setDefaultSort($a, FALSE);
        //$grid->setDataSource($this->database->table('ASSIGNMENT', 'a')->select("ASSIGNMENT.id,
        // ASSIGNMENT.name, CONCAT(creator.firstname, ' ', creator.lastname) AS creator_name, period.label"));
        $grid->setDataSource($this->database->table('ASSIGNMENT')->select('ASSIGNMENT.id, 
            ASSIGNMENT.name AS assignment_name, CONCAT(contact.firstname, " ", contact.lastname) AS creator_name')->where('user_id', NULL));

        $grid->setTemplateFile(__DIR__ . '/templates/DataGrid/basicTemplate.latte');

        //$grid->addColumnText('PROJECT.id', 'ID')->setSortable();
        //$grid->addColumnText('name', 'Název');
        //$grid->addColumnLink('name', 'Název', 'Assignment:show', 'name', ['id'])->setSortable()->setFilterText();
        //$grid->addColumnText('label', 'Období');
        //$grid->addColumnText('creator_name', 'Zadavatel');
        //$grid->addColumnText('assignment_name', 'Zadání');
        $grid->addColumnLink('assignment_name', 'Zadání', 'Assignment:show', 'assignment_name', ['id']);
        $grid->addColumnText('creator_name', 'Zadavatel');

    }

    public function canAccessPage(): bool {
        if(!$this->user->isLoggedIn()) {
            return false;
        } else if($this->user->isInRole(RoleManager::$ROLE_MENTOR)) {
            return true;
        }
        return false;
    }

}