<?php

namespace App\Components;

use App\Model\UserManager;
use Nette\Application\UI\Form;

/**
 * Form component class for edit contact information of user.
 * @package App\Components
 */
class ContactEditForm {

    protected UserManager $userManager;

    /**
     * Component constructor
     * @param UserManager $userManager
     */
    public function __construct(UserManager $userManager) {
        $this->userManager = $userManager;

    }

    /**
     * Factory function for creating assignment creation form
     * @param $userId access user identifier for restricting access
     * @return Form resulted Form instance
     */
    public function create($userId):Form {
        $defaults = [
            'firstname' => '',
            'lastname' => '',
            'email' => '',
            'phone' => '',
            'info' => '',
        ];

        $contact = $this->userManager->getContact($this->userManager->getUser($userId));

        if($contact) {
            $defaults['firstname'] = $contact['firstname'];
            $defaults['lastname'] = $contact['lastname'];
            $defaults['email'] = $contact['email'];
            $defaults['phone'] = $contact['phone'];
            $defaults['info'] = $contact['info'];
        }

        $form = new Form();

        $form->addText('firstname', 'Křestní jméno')
            ->setRequired('Položka musí být vyplněna.')
            ->setDefaultValue($defaults['firstname'])
            ->setHtmlAttribute('class', 'form-control');
        $form->addText('lastname', 'Příjmení')
            ->setRequired('Položka musí být vyplněna.')
            ->setDefaultValue($defaults['lastname'])
            ->setHtmlAttribute('class', 'form-control');
        $form->addText('email', 'Kontaktní email')
            ->setRequired('Položka musí být vyplněna.')
            ->setDefaultValue($defaults['email'])
            ->setHtmlAttribute('class', 'form-control');
        $form->addText('phone', 'Telefonní kontakt')
            ->setDefaultValue($defaults['phone'])
            ->setHtmlAttribute('class', 'form-control');
        $form->addTextArea('info', 'Další informace')
            ->setDefaultValue($defaults['info'])
            ->setHtmlAttribute('class', 'form-control');

        $form->addSubmit('send');

        return $form;

    }

}