<?php

namespace App\Components;

use App\Model\ConfigManager;
use App\Model\MailManager;
use App\Model\UserManager;
use App\Model\Utils;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Form component class for creating user with mentor permission
 * @package App\Component
 */
class MentorAddForm {

    protected UserManager $userManager;
    protected MailManager $mailManager;
    protected ConfigManager $configManager;

    /**
     * Component constructor
     * @param UserManager $userManager
     * @param MailManager $mailManager
     * @param ConfigManager $configManager
     */
    public function __construct(UserManager $userManager,
                                MailManager $mailManager,
                                ConfigManager $configManager) {
        $this->userManager = $userManager;
        $this->mailManager = $mailManager;
        $this->configManager = $configManager;

    }

    /**
     * Factory function for creating mentor creation form
     * @return Form
     */
    public function create():Form {
        $form = new Form();

        $form->addText('login', 'Login mentora')
            ->setRequired('Položka musí být zadána.')
            ->setHtmlAttribute('class', 'form-control');

        $form->addEmail('email', 'Email mentora')
            ->setRequired('Položka musí být zadána.')
            ->setHtmlAttribute('class', 'form-control');

        $form->addText('firstname', 'Křestní jméno mentora')
            ->setRequired('Položka musí být zadána.')
            ->setHtmlAttribute('class', 'form-control');

        $form->addText('lastname', 'Příjmení mentora')
            ->setRequired('Položka musí být zadána.')
            ->setHtmlAttribute('class', 'form-control');

        $form->addSubmit('send');

        $form->onSuccess[] = [$this, 'addMentor'];

        return $form;
    }

    /**
     * Functions that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function addMentor(Form $form, ArrayHash $values) {

        $password = Utils::getGeneratedPassword();

        if($this->configManager->getConfig()['testing']['enabled']) {
            if($this->configManager->getConfig()['testing']['testPassword']) {
                $password = $this->configManager->getConfig()['testing']['testPasswordValue'];
            }
        }

        $this->userManager->createMentorUser($values['login'], $password, $values['email'], $values['firstname'], $values['lastname']);

        $this->mailManager->sendMentorCreated($values['email'], $values['login'], $password);

    }

}