<?php

namespace App\Components;

use App\Model\UserManager;
use Nette\Application\UI\Form;
use Nette\Security\AuthenticationException;
use Nette\Security\User;
use Nette\Utils\ArrayHash;

/**
 * Form component class for password recovery
 * @package App\Components
 */
class PasswordRecoverForm extends Form {
    protected UserManager $userManager;

    protected User $user;

    /**
     * Component constructor
     * @param UserManager $userManager
     * @param User $user
     */
    public function __construct(UserManager $userManager, User $user) {
        $this->userManager = $userManager;
        $this->user = $user;
        parent::__construct();
    }

    /**
     * Factory function for creating password recovery form
     * @param $token
     * @return Form
     */
    public function create($token):Form {

        $form = new Form();
        $form->addPassword('password1', 'Uživatelské jméno:')->setRequired('Položka je povinná.')
            ->addRule(self::MIN_LENGTH, "Heslo musí být dlouhé alespoň %d znaků.", 8)
            ->addRule(self::PATTERN, 'Zadaný řetězec obsahuje nepovolené znaky.', '^[a-zA-Z0-9#?!@$%^&*-]*$')
            ->addRule(self::PATTERN, 'Heslo musí obsahovat alespoň jedno malé písmeno.', '^[a-zA-Z0-9#?!@$%^&*-]*[a-z]+[a-zA-Z0-9#?!@$%^&*-]*$')
            ->addRule(self::PATTERN, 'Heslo musí obsahovat alespoň jedno velké písmeno.', '^[a-zA-Z0-9#?!@$%^&*-]*[A-Z]+[a-zA-Z0-9#?!@$%^&*-]*$')
            ->addRule(self::PATTERN, 'Heslo musí obsahovat alespoň jedna číslice.', '^[a-zA-Z0-9#?!@$%^&*-]*[0-9]+[a-zA-Z0-9#?!@$%^&*-]*$');
        $form->addPassword('password2', 'Heslo:')->setRequired('Položka je povinná.')
            ->addRule(self::EQUAL, "Hesla se musí shodovat", $form['password1']);
        $form->addHidden('token', $token)->setRequired();
        $form->addSubmit('send', 'Změnit heslo');


        //$form->onValidate[] = [$this, 'validateForm'];
        $form->onSuccess[] = [$this, 'changePass'];
        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function changePass(Form $form, ArrayHash $values)  {

        if($values['password1'] != $values['password2']) {
            $form->addError("Hesla se neshodují.");
        }

        $this->userManager->recoverPassword($values['token'], $values['password1']);

    }
}