<?php

namespace App\Components;

use App\Model\ConfigManager;
use App\Model\PeriodManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Form component class for change actual period cycle TSP
 * @package App\Components
 */
class PeriodSettingForm {

    protected ConfigManager $configManager;
    protected PeriodManager $periodManager;

    /**
     * Component constructor
     * @param ConfigManager $configManager
     * @param PeriodManager $periodManager
     */
    public function __construct(ConfigManager $configManager,
                                PeriodManager $periodManager) {
        $this->configManager = $configManager;
        $this->periodManager = $periodManager;
    }

    /**
     * Factory function for creating period settings change form
     * @return Form
     */
    public function create():Form {

        $form = new Form();

        $periods = $this->periodManager->getAllPeriods();

        foreach ($periods as $period) {
            $periodsArray[$period->id] = $period->label;
        }


        $form->addSelect('period', 'Ročník aktuálního cyklu TSP', $periodsArray)
            ->setRequired('Položka musí být vyplněna')
            ->setDefaultValue($this->configManager->getActualPeriod())
            ->setHtmlAttribute('class', 'form-control');

        $form->addSubmit('send');

        $form->onSuccess[] = [$this, 'updatePeriod'];

        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function updatePeriod(Form $form, ArrayHash $values) {
        $this->configManager->setActualPeriod($values['period']);
    }

}