<?php

namespace App\Components;

use App\Model\UserManager;
use Nette\Application\UI\Form;
use Nette\Security\AuthenticationException;
use Nette\Security\User;
use Nette\Utils\ArrayHash;

/**
 * Form component class for forget password process
 * @package App\Components
 */
class SignForgetForm extends Form {
    protected UserManager $userManager;

    protected User $user;

    /**
     * Component constructor
     * @param UserManager $userManager
     * @param User $user
     */
    public function __construct(UserManager $userManager, User $user) {
        $this->userManager = $userManager;
        $this->user = $user;
        parent::__construct();
    }

    /**
     * Factory function for creating forget password process form
     * @return Form
     */
    public function create() {

        $form = new Form();
        $form->addEmail('email', 'E-mailová adresa:')->setRequired('Prosím vyplňte svou e-mailovou adresu.');
        $form->addSubmit('send', 'Přihlásit');


        //$form->onValidate[] = [$this, 'validateForm'];
        $form->onSuccess[] = [$this, 'saveForm'];
        return $form;
    }

    /**
     * Functions that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function saveForm(Form $form, ArrayHash $values) {
        try {
            //$this->user->login($values->username, $values->password);
            $this->userManager->forgetPassword($values->email);
        } catch (AuthenticationException $e) {
            //$this->loggerManager->get('default')->notice("Login fail, wrong password", ["login" => $values->username]);
            $form->addError('Nesprávné přihlašovací jméno nebo heslo.');
        }
    }
}