<?php

namespace App\Components;

use App\Model\ConfigManager;
use App\Model\MailManager;
use App\Model\StudentManager;
use App\Model\TeamManager;
use App\Model\UserManager;
use App\Model\Utils;
use Nette\Application\UI\Form;
use Nette\Forms\Rule;
use Nette\Utils\ArrayHash;

/**
 * Form component class for creating new team
 */
class TeamCreationForm {

    protected UserManager $userManager;
    protected StudentManager $studentManager;
    protected TeamManager $teamManager;
    protected MailManager $mailManager;
    protected ConfigManager $configManager;

    /**
     * Component constructor
     * @param UserManager $userManager
     * @param StudentManager $studentManager
     * @param TeamManager $teamManager
     * @param MailManager $mailManager
     * @param ConfigManager $configManager
     */
    public function __construct(UserManager $userManager,
                                StudentManager $studentManager,
                                TeamManager $teamManager,
                                MailManager $mailManager,
                                ConfigManager $configManager) {
        $this->userManager = $userManager;
        $this->studentManager = $studentManager;
        $this->teamManager = $teamManager;
        $this->mailManager = $mailManager;
        $this->configManager = $configManager;
    }

    /**
     * Factory function for creating team creation form
     * @param int $id
     * @return Form
     */
    public function create(int $id): Form {
        $form = new Form();

        $leader = $this->studentManager->getStudent($id);
        if (!$leader) {
            return $form;
        }

        $form->addText('teamName', "Název týmu")
            ->setRequired('Název týmu musí být povolen.')
            ->setHtmlAttribute('class', 'form-control');

        $form->addText('leaderName', 'Vedoucí týmu')
            ->setDefaultValue(Utils::getValidNameFromArgs($leader->firstname, $leader->lastname))
            ->setHtmlAttribute('class', 'form-control');

        $form->addHidden('leaderId', $id)->setRequired(true);

        $form->addSubmit('send')->setHtmlId("frm-teamCreationForm-submit");

        return $form;
    }

}