<?php

namespace App\Components;

use App\Model\TeamManager;
use Nette\Application\UI\Form;
use Nette\Utils\ArrayHash;

/**
 * Form component class for inserting credit records for a team
 * @package App\Components
 */
class TeamCreditForm {

    protected TeamManager $teamManager;

    /**
     * Component constructor
     * @param TeamManager $teamManager
     */
    public function __construct(TeamManager $teamManager) {
        $this->teamManager = $teamManager;
    }

    /**
     * Factory function for creating credit form
     * @param int $teamId identifier of edited team
     * @return Form resulted Form instance
     */
    public function create(int $teamId):Form {
        $team = $this->teamManager->getTeamById($teamId);
        $project = $team->related('PROJECT')->fetch();

        $form = new Form();

        $form->addText('creditTsp1', "Datum zápočtu TSP1")
            ->setHtmlType("date")
            ->setDefaultValue(!$project || empty($project['course_credit_tsp1']) ? "" : $project['course_credit_tsp1']->format('Y-m-d'))
            ->setHtmlAttribute("class","form-control");

        $form->addText('creditTsp2', "Datum zápočtu TSP2")
            ->setHtmlType("date")
            ->setDefaultValue(!$project || empty($project['course_credit_tsp2']) ? "" : $project['course_credit_tsp2']->format('Y-m-d'))
            ->setHtmlAttribute("class","form-control");

        $form->addHidden('teamId', $teamId);

        $form->addSubmit('send');

        $form->onSuccess[] = [$this, 'saveForm'];

        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function saveForm(Form $form, ArrayHash $values) {

        $this->teamManager->updateCredit($values['teamId'], $values['creditTsp1'], $values['creditTsp2']);
    }


}