<?php

namespace App\Components;

use App\Model\MeetingFacade;
use App\Model\StudentManager;
use App\Model\TeamManager;
use App\Model\TagManager;
use App\Model\UserManager;
use http\Exception;
use Nette\Application\AbortException;
use Nette\Application\UI\Form;
use Nette\Database\Explorer;
use Nette\Security\AuthenticationException;
use Nette\Security\User;
use Nette\Utils\ArrayHash;

/**
 * Form component class for editing meeting information
 * @package App\Components
 */
class TeamMeetingInfoForm extends Form {
    protected MeetingFacade $meetingFacade;

    /**
     * Component constructor
     * @param MeetingFacade $meetingFacade
     */
    public function __construct(MeetingFacade $meetingFacade) {
        parent::__construct();
       $this->meetingFacade = $meetingFacade;
    }

    /**
     * Factory function for creating meeting information edit form
     * @param int $meetingId
     * @return Form
     */
    public function create(int $meetingId = -1) {
        $defaultMeeting = null;
        $form = new Form();
        if ($meetingId >= 0) {
            $defaultMeeting = $this->meetingFacade->getMeeting($meetingId);
        }

        $form->addHidden("meetingId",$meetingId);
        $form->addText("meetingDate", "Čas schůzky")
            ->setHtmlAttribute('class="form-control"')
            ->setDefaultValue($defaultMeeting->datetime->format('j.n.Y G:i'))
            ->setHtmlAttribute("readonly");

        $form->addText("meetingRoom", "Název místnosti")
            ->setHtmlAttribute('class="form-control"')
            ->setDefaultValue($defaultMeeting->place)
            ->setHtmlAttribute("readonly");

        $form->addText("meetingTopic", "Téma schůzky")
            ->setHtmlAttribute('class="form-control"')
            ->setDefaultValue($defaultMeeting->info)
            ->setHtmlAttribute("readonly");

        $form->addTextArea("meetingInfo", "Podrobný zápis ze schůzky",null,8)
            ->setHtmlAttribute('class="form-control"')
            ->setDefaultValue($defaultMeeting->detail_info);


        $form->addSubmit('save', 'Potvrdit změny')
        ->setHtmlId("frm-editMeetingTopicForm-submit");
        $form->addButton('cancel', 'Zrušit')
            ->setHtmlId("frm-editMeetingTopicForm-cancel");
        //$form->onValidate[] = [$this, 'validateForm'];
        $form->onSuccess[] = [$this, 'saveForm'];

        return $form;
    }

    /**
     * Function that is triggered by a successful form submission
     * @param Form $form
     * @param ArrayHash $values
     */
    public function saveForm(Form $form, ArrayHash $values) {
        try {
            $this->meetingFacade->getMeeting($values['meetingId'])->update([
                "detail_info"=>$values["meetingInfo"]
            ]);
        } catch (\Exception $e) {

        }
    }
}